pub struct ListTypefacesFlags(/* private fields */);Implementations
Sourceimpl ListTypefacesFlags
impl ListTypefacesFlags
Sourcepub const MATCH_FAMILY_NAME_SUBSTRING: ListTypefacesFlags
pub const MATCH_FAMILY_NAME_SUBSTRING: ListTypefacesFlags
Match families whose name or alias exactly contains the requested
FamilyName. If not set, match families whose name or alias exactly
matches FamilyName.
Note: Matching will always ignore case.
Sourceimpl ListTypefacesFlags
impl ListTypefacesFlags
Sourcepub const fn empty() -> ListTypefacesFlags
pub const fn empty() -> ListTypefacesFlags
Get a flags value with all bits unset.
Sourcepub const fn all() -> ListTypefacesFlags
pub const fn all() -> ListTypefacesFlags
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<ListTypefacesFlags>
pub const fn from_bits(bits: u32) -> Option<ListTypefacesFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> ListTypefacesFlags
pub const fn from_bits_truncate(bits: u32) -> ListTypefacesFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> ListTypefacesFlags
pub const fn from_bits_retain(bits: u32) -> ListTypefacesFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<ListTypefacesFlags>
pub fn from_name(name: &str) -> Option<ListTypefacesFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: ListTypefacesFlags) -> bool
pub const fn intersects(&self, other: ListTypefacesFlags) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: ListTypefacesFlags) -> bool
pub const fn contains(&self, other: ListTypefacesFlags) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: ListTypefacesFlags)
pub fn insert(&mut self, other: ListTypefacesFlags)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: ListTypefacesFlags)
pub fn remove(&mut self, other: ListTypefacesFlags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: ListTypefacesFlags)
pub fn toggle(&mut self, other: ListTypefacesFlags)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: ListTypefacesFlags, value: bool)
pub fn set(&mut self, other: ListTypefacesFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: ListTypefacesFlags) -> ListTypefacesFlags
pub const fn intersection(self, other: ListTypefacesFlags) -> ListTypefacesFlags
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: ListTypefacesFlags) -> ListTypefacesFlags
pub const fn union(self, other: ListTypefacesFlags) -> ListTypefacesFlags
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: ListTypefacesFlags) -> ListTypefacesFlags
pub const fn difference(self, other: ListTypefacesFlags) -> ListTypefacesFlags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: ListTypefacesFlags,
) -> ListTypefacesFlags
pub const fn symmetric_difference( self, other: ListTypefacesFlags, ) -> ListTypefacesFlags
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> ListTypefacesFlags
pub const fn complement(self) -> ListTypefacesFlags
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl ListTypefacesFlags
impl ListTypefacesFlags
Sourcepub const fn iter(&self) -> Iter<ListTypefacesFlags> ⓘ
pub const fn iter(&self) -> Iter<ListTypefacesFlags> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<ListTypefacesFlags> ⓘ
pub const fn iter_names(&self) -> IterNames<ListTypefacesFlags> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.