TypefaceInfo

Struct TypefaceInfo 

pub struct TypefaceInfo {
    pub asset_id: Option<u32>,
    pub font_index: Option<u32>,
    pub family: Option<FamilyName>,
    pub style: Option<Style2>,
    pub languages: Option<Vec<LocaleId>>,
    pub generic_family: Option<GenericFontFamily>,
    /* private fields */
}
Collection of typeface metadata that should be sufficient for clients to perform some kind of selection (likely via human) and request an exact font.

Fields

asset_id: Option<u32>

Identifier for the font asset. This ID is valid for the lifetime of the font service. May be used in conjunction with font_index to directly request this font.

font_index: Option<u32>

Index of the font within its parent asset. May be used in conjunction with asset_id to directly request this font.

family: Option<FamilyName>style: Option<Style2>languages: Option<Vec<LocaleId>>generic_family: Option<GenericFontFamily>